import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as ComponentStories from "./locale-selection-banner.stories";

<Meta of={ComponentStories} name="Docs" />

# Locale Selection Banner

The locale selection banner component, responsible to get the locales data asynchronously from the API endpoint. <br />
The banner will request the data on component load, and once this has been received, the component will animate itself into
the viewport. <br />
The description of the various properties can be found below.

<Canvas of={ComponentStories.Default}></Canvas>

## No Show

If the key `showLocaleSelectionBanner` from the API response is not present or not set to true,
the component will not appear on the screen.

<Canvas of={ComponentStories.NoShow}></Canvas>

## API Response

From the API the component expects a JSON response with the following keys:
`showLocaleSelectionBanner`, `availableLocales`, `descriptionText`, `activeLocale` and `buttonText`. <br />
The `availableLocales` is an array of available languages, each containing the keys: `uid`, `localeLabel`, `languageISOCode`,
`localeURL`, `localeValue`. In addition, the language that will be suggested to the user will have
the additional key `preselected` with value set to `true`. <br />
If the key `showLocaleSelectionBanner` is not present or not set to `true`, the banner will not be shown.
Here is an example:

```
{
    "showLocaleSelectionBanner": true,
    "activeLocale": "7",
    "descriptionText": "Sie haben United Kingdom ausgewählt. Anhand Ihrer Konfiguration wäre Deutschland ggf. passender. Möchten Sie die Auswahl beibehalten oder ändern?",
    "buttonText": "accept",
    "availableLocales": [
        {
            "localeLabel": "Brazil",
            "languageISOCode": "34",
            "localeURL": "https://www.trumpf.com/pt_BR/empresa/grupotrumpf/diretoria/",
            "localeValue": "br_BR",
            "preselected": true
        },
        {
            "localeLabel": "Italia",
            "languageISOCode": "35",
            "localeURL": "https://www.trumpf.com/it_IT/impresa/gruppo-trumpf/management/",
            "localeValue": "it_IT"
        },
        [...]
    ]
}
```

When the key `showLocaleSelectionBanner` is set to `false`, it is not necessary to deliver a list of available locales,
since the banner will not be shown.

```
{
     "showLocaleSelectionBanner": false
}
```

## Developer Documentation

<Controls />
